# by Sacha Epskamp, adapted by Eiko Fried for:
# http://psych-networks.com/network-stability-part-ii-common-problems-and-questions/

# Some pcor network:
net <- matrix(0,18,18)
net[1:9,1:9] <- 0.1
net[10:18,10:18] <- 0.1

# Two bridges:
net[1,10] <- net[10,1] <- 0.05
net[2,11] <- net[11,2] <- 0.05
diag(net) <- 0

# Draw:
library("qgraph")
qgraph(net, layout = "spring", theme = "colorblind", 
       title = "Pcor network", esize = 2, vsize = 5)

# Generate data and bootstrap
library("bootnet")
set.seed(1)
Data <- ggmGenerator()(5000, net)
boots <- bootnet(Data, default = "EBICglasso", type = "case", nCores = 8)
plot(boots)
corStability(boots) # CS coefficient of 0 for Betweenness

# Simulation study using this pcor network:
library("bootnet")
Results <- netSimulator(net,default="EBICglasso",
                        nCase = c(250,500,1000,2500,5000,10000),
                        nCores = 8, nReps = 100)

# Network structure:
plot(Results) + theme(legend.position = "top") + 
  ggtitle("Network estimation")

# Centrality:
plot(Results,yvar = c("strength", "closeness", "betweenness") ) + 
  theme(legend.position = "top")+ 
  ggtitle("Centrality correlation")

